@@ -1,9 +1,9 @@
 from collections import OrderedDict
 
 from django.db.models import Q
-from rest_framework import mixins, viewsets
 from rest_framework import generics
 from rest_framework import serializers
+from rest_framework import viewsets
 from rest_framework.pagination import PageNumberPagination
 from rest_framework.response import Response
 
@@ -92,14 +92,13 @@ class BaseSelect2View(generics.ListAPIView, viewsets.GenericViewSet):
                 q = []
         return q
 
-
     def filter_queryset(self, queryset):
         q = self.query_get('term', '')
         self.selected = self.query_get('selected', '')
         if self.ref_field is not None:
             relq = self.query_get(self.ref_name, '')
             if relq:
-                queryset = queryset.filter(**{self.ref_field+'__in': relq})
+                queryset = queryset.filter(**{self.ref_field + '__in': relq})
             else:
                 queryset = queryset.none()
 
@@ -109,9 +108,9 @@ class BaseSelect2View(generics.ListAPIView, viewsets.GenericViewSet):
 
     def get_queryset(self):
         assert self.model is not None, (
-                "'%s' should either include a `model` attribute, "
-                "or override the `get_queryset()` method."
-                % self.__class__.__name__
+            "'%s' should either include a `model` attribute, "
+            "or override the `get_queryset()` method."
+            % self.__class__.__name__
         )
         return self.model.objects.all().order_by(self.order_by)
 
@@ -136,7 +135,7 @@ class BaseSelect2View(generics.ListAPIView, viewsets.GenericViewSet):
         if func is not None:
             dev = func(dev)
         if self.text_wrapper:
-            dev = self.text_wrapper%dev
+            dev = self.text_wrapper % dev
         return dev
 
     def get_id_display(self, obj):
@@ -156,4 +155,4 @@ class BaseSelect2View(generics.ListAPIView, viewsets.GenericViewSet):
         return self.view.get_selected_display(obj)
 
     def get_disabled_display(self, obj):
-        return False
\ No newline at end of file
+        return False
